Index: /branches/coll_rect/src/lib/collision_reaction/collision_filter.h
===================================================================
--- /branches/coll_rect/src/lib/collision_reaction/collision_filter.h	(revision 9894)
+++ /branches/coll_rect/src/lib/collision_reaction/collision_filter.h	(revision 9895)
@@ -4,6 +4,6 @@
 */
 
-#ifndef _COLLISION_HANDLE_H
-#define _COLLISION_HANDLE_H
+#ifndef _COLLISION_FILTER_H
+#define _COLLISION_FILTER_H
 
 #include "base_object.h"
@@ -25,11 +25,11 @@
 
   //! A class for defining collision reactions and storing events
-  class CollisionHandle : public BaseObject
+  class CollisionFilter : public BaseObject
   {
-    ObjectListDeclaration(CollisionHandle);
+    ObjectListDeclaration(CollisionFilter);
 
   public:
-    CollisionHandle(WorldEntity* owner, CREngine::ReactionType type);
-    virtual ~CollisionHandle();
+    CollisionFilter(WorldEntity* owner, CREngine::ReactionType type);
+    virtual ~CollisionFilter();
 
     void reset();
@@ -73,3 +73,3 @@
 
 }
-#endif /* _COLLISION_HANDLE_H */
+#endif /* _COLLISION_FILTER_H */
Index: /branches/coll_rect/src/lib/collision_reaction/cr_engine.cc
===================================================================
--- /branches/coll_rect/src/lib/collision_reaction/cr_engine.cc	(revision 9894)
+++ /branches/coll_rect/src/lib/collision_reaction/cr_engine.cc	(revision 9895)
@@ -20,5 +20,5 @@
 #include "collision.h"
 #include "collision_event.h"
-#include "collision_handle.h"
+#include "collision_filter.h"
 #include "cr_defs.h"
 
@@ -122,13 +122,13 @@
   void CREngine::reset()
   {
-    // first clear all CollisionHandles
-    std::vector<CollisionHandle*>::iterator it = this->collisionHandles.begin();
-    for(; it < this->collisionHandles.end(); it++)
-    {
-      (*it)->reset();
-      delete *it;
-    }
-
-    this->collisionHandles.clear();
+//     // first clear all CollisionHandles
+//     std::vector<CollisionHandle*>::iterator it = this->collisionHandles.begin();
+//     for(; it < this->collisionHandles.end(); it++)
+//     {
+//       (*it)->reset();
+//       delete *it;
+//     }
+//
+//     this->collisionHandles.clear();
   }
 
@@ -140,11 +140,11 @@
    *  @return the newly created CollisionHandle
    */
-  CollisionHandle* CREngine::subscribeReaction(WorldEntity* owner, ReactionType type)
-  {
-    CollisionHandle* ch = new CollisionHandle(owner, type);
-    this->collisionHandles.push_back(ch);
-
-    return ch;
-  }
+//   CollisionHandle* CREngine::subscribeReaction(WorldEntity* owner, ReactionType type)
+//   {
+//     CollisionHandle* ch = new CollisionHandle(owner, type);
+//     this->collisionHandles.push_back(ch);
+//
+//     return ch;
+//   }
 
 
@@ -154,18 +154,18 @@
    *  @param returns true if worked collrectly
    */
-  bool CREngine::unsubscribeReaction(CollisionHandle* collisionHandle)
-  {
-    std::vector<CollisionHandle*>::iterator it;
-    for( it = this->collisionHandles.begin(); it != this->collisionHandles.end(); it++)
-    {
-      if( *it == collisionHandle)
-      {
-        this->collisionHandles.erase(it);
-        delete collisionHandle;
-        return true;
-      }
-    }
-    return false;
-  }
+//   bool CREngine::unsubscribeReaction(CollisionHandle* collisionHandle)
+//   {
+//     std::vector<CollisionHandle*>::iterator it;
+//     for( it = this->collisionHandles.begin(); it != this->collisionHandles.end(); it++)
+//     {
+//       if( *it == collisionHandle)
+//       {
+//         this->collisionHandles.erase(it);
+//         delete collisionHandle;
+//         return true;
+//       }
+//     }
+//     return false;
+//   }
 
 
@@ -175,13 +175,13 @@
   void CREngine::handleCollisions()
   {
-    std::vector<CollisionHandle*>::iterator it;
-    for( it = this->collisionHandles.begin(); it != this->collisionHandles.end(); it++)
-    {
-      if( !(*it)->isDispatched() || (*it)->isContinuousPoll())  //does it have any collisions to report at all
-      {
-        (*it)->handleCollisions();
-      }
-    }
-    this->flushCollisions();
+//     std::vector<CollisionHandle*>::iterator it;
+//     for( it = this->collisionHandles.begin(); it != this->collisionHandles.end(); it++)
+//     {
+//       if( !(*it)->isDispatched() || (*it)->isContinuousPoll())  //does it have any collisions to report at all
+//       {
+//         (*it)->handleCollisions();
+//       }
+//     }
+//     this->flushCollisions();
   }
 
Index: /branches/coll_rect/src/lib/collision_reaction/cr_engine.h
===================================================================
--- /branches/coll_rect/src/lib/collision_reaction/cr_engine.h	(revision 9894)
+++ /branches/coll_rect/src/lib/collision_reaction/cr_engine.h	(revision 9895)
@@ -21,5 +21,4 @@
 namespace CoRe
 {
-  class CollisionHandle;
   class Collision;
   class CollisionEvent;
@@ -61,15 +60,4 @@
 
 
-#define COLLISION_TYPE_AXIS_X      1
-#define COLLISION_TYPE_AXIS_X_NEG  2
-//!< the collision axis y collision event
-#define COLLISION_TYPE_AXIS_Y      3
-#define COLLISION_TYPE_AXIS_Y_NEG  4
-//!< the collision axis z collision event
-#define COLLISION_TYPE_AXIS_Z      5
-#define COLLISION_TYPE_AXIS_Z_NEG  6
-//!< the collision is a obb collision
-#define COLLISION_TYPE_OBB         8
-
     virtual ~CREngine(void);
 
@@ -77,6 +65,6 @@
     inline static CREngine* getInstance() { if (!singletonRef) singletonRef = new CREngine();  return singletonRef; };
 
-    CollisionHandle* subscribeReaction(WorldEntity* worldEntity, ReactionType type);
-    bool unsubscribeReaction(CollisionHandle* collisionHandle);
+//     CollisionHandle* subscribeReaction(WorldEntity* worldEntity, ReactionType type);
+//     bool unsubscribeReaction(CollisionHandle* collisionHandle);
 
 
@@ -98,5 +86,5 @@
 
   private:
-    std::vector<CollisionHandle*>       collisionHandles;         //!< list with the collision handles
+    //std::vector<CollisionHandle*>       collisionHandles;         //!< list with the collision handles
 
     std::vector<Collision*>             collisionsUsed;           //!< a list of used, cached collisions
Index: /branches/coll_rect/src/lib/collision_reaction/cr_physics_full_walk.cc
===================================================================
--- /branches/coll_rect/src/lib/collision_reaction/cr_physics_full_walk.cc	(revision 9894)
+++ /branches/coll_rect/src/lib/collision_reaction/cr_physics_full_walk.cc	(revision 9895)
@@ -96,5 +96,5 @@
       {
           /* collision in the X-AXIS */
-          case COLLISION_TYPE_AXIS_X:
+        case CoRe::CREngine::CR_COLLISION_TYPE_AXIS_X:
           front = collPos.len() - box->halfLength[0];
 
@@ -116,5 +116,5 @@
           break;
 
-          case COLLISION_TYPE_AXIS_X_NEG:
+        case CoRe::CREngine::CR_COLLISION_TYPE_AXIS_X_NEG:
           back = collPos.len() - box->halfLength[0];
 
@@ -138,5 +138,5 @@
 
           /* collision in the Y-AXIS */
-          case COLLISION_TYPE_AXIS_Y_NEG:
+        case CoRe::CREngine::CR_COLLISION_TYPE_AXIS_Y_NEG:
           // calulate the height above ground
           height = collPos.len() - box->halfLength[1];
@@ -165,5 +165,5 @@
 
           /* collision in the Z-AXIS */
-          case COLLISION_TYPE_AXIS_Z:
+        case CoRe::CREngine::CR_COLLISION_TYPE_AXIS_Z:
 
           right = collPos.len()  - box->halfLength[2];
@@ -187,5 +187,5 @@
 
           // collision in the z-axis
-          case COLLISION_TYPE_AXIS_Z_NEG:
+        case CoRe::CREngine::CR_COLLISION_TYPE_AXIS_Z_NEG:
 
           left = collPos.len()  - box->halfLength[2];
Index: /branches/coll_rect/src/lib/collision_reaction/cr_physics_ground_walk.cc
===================================================================
--- /branches/coll_rect/src/lib/collision_reaction/cr_physics_ground_walk.cc	(revision 9894)
+++ /branches/coll_rect/src/lib/collision_reaction/cr_physics_ground_walk.cc	(revision 9895)
@@ -94,5 +94,5 @@
       {
           /* collision in the Y-AXIS */
-          case COLLISION_TYPE_AXIS_Y_NEG:
+        case CoRe::CREngine::CR_COLLISION_TYPE_AXIS_Y_NEG:
           // calulate the height above ground
           height = collPos.len() - box->halfLength[1];

Index: /branches/coll_rect/src/lib/collision_reaction/collision_filter.cc
===================================================================
--- /branches/coll_rect/src/lib/collision_reaction/collision_filter.cc	(revision 9894)
+++ /branches/coll_rect/src/lib/collision_reaction/collision_filter.cc	(revision 9895)
@@ -15,5 +15,5 @@
 #define DEBUG_SPECIAL_MODULE DEBUG_MODULE_COLLISION_REACTION
 
-#include "collision_handle.h"
+#include "collision_filter.h"
 
 #include "world_entity.h"
@@ -32,5 +32,5 @@
 {
 
-  ObjectListDefinition(CollisionHandle);
+  ObjectListDefinition(CollisionFilter);
 
   /**
@@ -38,7 +38,7 @@
    * @todo this constructor is not jet implemented - do it
   */
-  CollisionHandle::CollisionHandle (WorldEntity* owner, CREngine::ReactionType type)
-  {
-    this->registerObject(this, CollisionHandle::_objectList);
+  CollisionFilter::CollisionFilter (WorldEntity* owner, CREngine::ReactionType type)
+  {
+    this->registerObject(this, CollisionFilter::_objectList);
 
     this->owner = owner;
@@ -76,5 +76,5 @@
    * standard deconstructor
   */
-  CollisionHandle::~CollisionHandle ()
+  CollisionFilter::~CollisionFilter ()
   {
     // delete what has to be deleted here
@@ -84,7 +84,7 @@
 
   /**
-   * restores the CollisionHandle to its initial state
-   */
-  void CollisionHandle::reset()
+   * restores the CollisionFilter to its initial state
+   */
+  void CollisionFilter::reset()
   {
     this->flushCollisions();
@@ -96,5 +96,5 @@
    *  @param classID the classid to look for
    */
-  void CollisionHandle::addTarget(const ClassID& target)
+  void CollisionFilter::addTarget(const ClassID& target)
   {
     // make sure there is no dublicate
@@ -114,5 +114,5 @@
    * handles the collisions and react according to algorithm
    */
-  void CollisionHandle::handleCollisions()
+  void CollisionFilter::handleCollisions()
   {
     // if continuous poll the reaction
@@ -146,5 +146,5 @@
    *  @param collisionEvent the collision event to filter
    */
-  bool CollisionHandle::filterCollisionEvent(CollisionEvent* collisionEvent)
+  bool CollisionFilter::filterCollisionEvent(CollisionEvent* collisionEvent)
   {
     std::vector<ClassID>::iterator it = this->targetList.begin();
@@ -201,5 +201,5 @@
    *  @param collision the collision object to filter
    */
-  bool CollisionHandle::filterCollision(Collision* collision)
+  bool CollisionFilter::filterCollision(Collision* collision)
   {
     std::vector<ClassID>::iterator it = this->targetList.begin();